@@ -3,6 +3,8 @@ import sys
 from time import sleep
 from uuid import UUID, uuid4 as _uuid4, _uuid_generate_random
 
+from kombu.utils.encoding import safe_repr as _safe_repr
+
 try:
     import ctypes
 except:
@@ -22,13 +24,14 @@ def uuid4():
     return _uuid4()
 
 
-def gen_unique_id():
+def uuid():
     """Generate a unique id, having - hopefully - a very small chance of
     collission.
 
     For now this is provided by :func:`uuid.uuid4`.
     """
     return str(uuid4())
+gen_unique_id = uuid
 
 
 if sys.version_info >= (3, 0):
@@ -257,3 +260,13 @@ class cached_property(object):
 
     def deleter(self, fdel):
         return self.__class__(self.__get, self.__set, fdel)
+
+
+def reprkwargs(kwargs, sep=', ', fmt="%s=%s"):
+    return sep.join(fmt % (k, _safe_repr(v)) for k, v in kwargs.iteritems())
+
+
+def reprcall(name, args=(), kwargs=(), sep=', '):
+    return "%s(%s%s%s)" % (name, sep.join(map(_safe_repr, args)),
+                           (args and kwargs) and sep or "",
+                           reprkwargs(kwargs, sep))
